@@ -28,10 +28,10 @@ class tchan {
     int updatenicklist();
     int clearnicklist();
     int changenick(char *, char *);
-    int deop(char *);
-    int op(char *);
-    int devoice(char *);
-    int voice(char *);
+    void deop(char *);
+    void op(char *);
+    void devoice(char *);
+    void voice(char *);
     void setmode(char, int);
     int getmode(char);
     void clearmodes(void);
