@@ -31,6 +31,7 @@
 // Add no connect warnings to sendata et all.
 
 tdcc::~tdcc() {
+  free(nick);
   Tcl_DeleteFileHandler(sockfd);
 }
 
@@ -153,7 +154,7 @@ int tdcc::getsockfd() {
   return sockfd;
 }
 
-tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport) {
+tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport) {
   // DCC CHAT ACCEPT
   twindow window;
   twindow *windowp;
@@ -162,6 +163,8 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport) {
   int windowexists=0;
   char assemble[TEMPLEN];
   
+  nick = mystrdup("");
+
   strcpy(window.name,"=");
   strcat(window.name,thenick);
   windows.init_trav();
@@ -223,7 +226,7 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport) {
     type=DCCCHAT;
     filefd=0;
 
-    strcpy(nick,thenick);
+    setnick(thenick);
     strcpy(ip,theip);
     port=theport;
     server=serverp;
@@ -287,7 +290,7 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport) {
   }
 }
 
-tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport, char *thefile, int thesize, int dccflags, char *renamedfile) {
+tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport, char *thefile, int thesize, int dccflags, char *renamedfile) {
   // DCC SEND ACCEPT
   twindow window;
   struct sockaddr_in addr;
@@ -295,6 +298,8 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport, char *thef
   tdccentry dccentry;
   int n;
   
+  nick = mystrdup(thenick);
+
   sprintf(window.pathname,".files%d",serverp->index);
   if(!windows.find(window)) {
     strcat(window.name,"DCC Files");
@@ -357,7 +362,6 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *theip, int theport, char *thef
   strcat(destfile,renamedfile);
   
   strcpy(file,thefile);
-  strcpy(nick,thenick);
   strcpy(ip,theip);
   port=theport;
   server=serverp;
@@ -405,13 +409,13 @@ tdcc::tdcc(tserver *serverp, char *thenick) {
   struct sockaddr_in my_addr;
   socklen_t my_addr_len=sizeof(struct sockaddr);
   
-  if(!strcasecmp(thenick,serverp->mynick)) {
+  nick = mystrdup(thenick);
+
+  if(!strcasecmp(thenick,serverp->getmynick())) {
     echo(" \0030,5 ERROR \003 You cannot DCC Chat yourself.",serverp->pathname,1);
     return;
   }
 
-  strcpy(nick,thenick);
-
   strcpy(window.name,"=");
   strcat(window.name,nick);
   windows.init_trav();
@@ -550,7 +554,8 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *thefile) {
   FILE *myfile;
   tdccentry dccentry;
 
-  strcpy(nick,thenick);
+  nick = mystrdup(thenick);
+
   strcpy(file,thefile);
 
   if((p=rindex(file,'/'))) {
