@@ -179,10 +179,11 @@ void tserver::ial_prefix(char *prefix) {
 
 void tserver::ial_add(char *nick, char *userhost) {
   int n;
-  char tempnick[NICKNAMELEN+1];
-  for(n=0;n<=(signed)strlen(nick);n++) tempnick[n]=tolower(nick[n]);
-  //ial[tempnick]=userhost;
+  char *tempnick = mystrdup(nick);
+  lc(tempnick);
+
   hash_set(&ial,tempnick,userhost);  
+  free(tempnick);
 }
 
 void tserver::perror(char *message) {
@@ -201,6 +202,7 @@ void tserver::perror(char *message, int number) {
 }
 
 tserver::~tserver() {
+  free(mynick);
   hash_destroy(&ial);
   if(name) free(name);
   if(desc) free(desc);
@@ -255,6 +257,8 @@ tserver::tserver(char *address, int theport, char *password) {
   twindow window;
   int n;
 
+  mynick = mystrdup("");
+
   if(!strlen(address)) {
     strcpy(ip,TT_Str(TT_ARGS,"set ::dynamic::default_server"));
   } else {
@@ -345,9 +349,9 @@ void tserver::server(char *address, int theport, char *password) {
 
   // Do rest of stuff
    
-  strcpy(mynick,TT_Str(TT_ARGS,"set ::dynamic::default_nick"));
-  name=strdup(TT_Str(TT_ARGS,"set ::dynamic::default_user"));
-  desc=strdup(TT_Str(TT_ARGS,"set ::dynamic::default_desc"));
+  setmynick(TT_Str(TT_ARGS,"set ::dynamic::default_nick"));
+  name=mystrdup(TT_Str(TT_ARGS,"set ::dynamic::default_user"));
+  desc=mystrdup(TT_Str(TT_ARGS,"set ::dynamic::default_desc"));
 
   pass=password;
 
@@ -390,7 +394,6 @@ void tserver::usedata() {
   int n,i;
   tchan chan;
   tchan *chanp;
-  tnick nick;
   
   while((position=strstr(buffer,"\xA"))) {
     
@@ -418,7 +421,7 @@ void tserver::usedata() {
       if(strcmp(command,"272") &&
 	 /* Offline WATCH Message */
 	 strcmp(command,"601")) {
-	strcpy(mynick,params[0]);
+	setmynick(params[0]);
       }
     }
 
@@ -497,7 +500,7 @@ void tserver::usedata() {
     
     if(!strcasecmp(command,"MODE")) {
       if(!ischannel(params[0])) {
-	strcpy(mynick,params[0]);
+	setmynick(params[0]);
 	if(!otherevents) {
 	  for(i=0;i<(signed)strlen(params[1]);i++) {
 	    switch(params[1][i]) {
@@ -621,31 +624,35 @@ void tserver::usedata() {
       strcpy(temp,prefix);
       strtok(temp,"!");
       {
-	char tempnick[NICKNAMELEN+1];
-	char tempnick2[NICKNAMELEN+1];
-	for(n=0;n<=(signed)strlen(temp);n++) tempnick[n]=tolower(temp[n]);
-	for(n=0;n<=(signed)strlen(params[0]);n++) tempnick2[n]=tolower(params[0][n]);
-	//ial[tempnick2]=ial[tempnick];
+	char *tempnick = mystrdup(temp);
+	char *tempnick2 = mystrdup(params[0]);
+	lc(tempnick);
+	lc(tempnick2);
+
 	hash_set(&ial,tempnick2,hash_get(&ial,tempnick));  
+
+	free(tempnick);
+	free(tempnick2);
       }
       
       if(!strcmp(temp,mynick)) {
-	strcpy(mynick,params[0]);
+	setmynick(params[0]);
       }
-      strcpy(nick.name,temp);
+
+      tnick nick(temp);
+
       chanlist.init_trav();
       while((chanp=chanlist.trav())) {
 	if(chanp->nicklist.find(nick)) {
 	  chanp->changenick(temp,params[0]);
 	}
       }
-      tquery query;
+      tquery query(temp);
       tquery *queryp;
-      strcpy(query.name,temp);
       if((queryp=querylist.find(query))) {
-	strcpy(query.name,params[0]);
+	query.setname(params[0]);
 	if(!querylist.find(query)) {
-	  strcpy(queryp->name,params[0]);
+	  queryp->setname(params[0]);
 	  TT_EvalF(TT_ARGS,"renamewindow %q %q",queryp->pathname,params[0]);
 	}
       }
@@ -806,7 +813,9 @@ void tserver::usedata() {
     if(!strcasecmp(command,"QUIT")) {
       strcpy(temp,prefix);
       strtok(temp,"!");
-      strcpy(nick.name,temp);
+
+      tnick nick(temp);
+
       chanlist.init_trav();
       while((chanp=chanlist.trav())) {
 	if(chanp->nicklist.find(nick)) {
@@ -819,7 +828,7 @@ void tserver::usedata() {
       strcpy(chan.name,params[0]);
       if((chanp=chanlist.find(chan))) {
 	if(chanp->topic) free(chanp->topic);
-	chanp->topic=strdup(params[1]);
+	chanp->topic=mystrdup(params[1]);
       }
     }
     
@@ -842,14 +851,14 @@ void tserver::usedata() {
     
     /* Reply to WHOIS (First line) */
     if(!strcmp(command,"311")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       sprintf(assemble,"%s@%s",params[2],params[3]);
       ial_add(params[1],assemble);
     }
     
     /* Reply to WHOWAS (First line) */
     if(!strcmp(command,"314")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       sprintf(assemble,"%s@%s",params[2],params[3]);
       ial_add(params[1],assemble);
     }
@@ -857,7 +866,7 @@ void tserver::usedata() {
     /* Mode settings for channel */
     //:raptor.ab.ca.dal.net 324 Hynato_C #asdfkjhaf +tnlk 45 346
     if(!strcasecmp(command,"324")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       strcpy(chan.name,params[1]);
       if((chanp=chanlist.find(chan))&&chanp->ison) {
 	chanp->clearmodes();
@@ -900,11 +909,11 @@ void tserver::usedata() {
     
     /* Reply to TOPIC check */
     if(!strcmp(command,"332")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       strcpy(chan.name,params[1]);
       if((chanp=chanlist.find(chan))) {
 	if(chanp->topic) free(chanp->topic);
-	chanp->topic=strdup(params[2]);
+	chanp->topic=mystrdup(params[2]);
       }
     }
     
@@ -916,7 +925,7 @@ void tserver::usedata() {
     
     /* Reply to NAMES */
     if(!strcmp(command,"353")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       if(hide.n353) {
 	parsed=1;
 	if(!strcmp(params[1],"=")) {
@@ -944,7 +953,7 @@ void tserver::usedata() {
     
     /* End of NAMES Reply */
     if(!strcmp(command,"366")) {
-      strcpy(mynick,params[0]);
+      setmynick(params[0]);
       if(hide.n366) {
 	parsed=1;
 	strcpy(chan.name,params[1]);
@@ -1229,7 +1238,7 @@ int tserver::do_connect(void) {
 
   fcntl(sockfd, F_SETFL, O_NONBLOCK);
 
-  strcpy(mynick,TT_Str(TT_ARGS,"set ::dynamic::default_nick"));
+  setmynick(TT_Str(TT_ARGS,"set ::dynamic::default_nick"));
 
   fdisplay("CONNECT_ATTEMPT",index,1,inet_ntoa(*((struct in_addr *)h->h_addr)));
 
