@@ -52,7 +52,7 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
 	Tcl_SetResult(interp,"acceptlist: Invalid arguments given",TCL_VOLATILE);
 	return TCL_ERROR;
       }
-      strcpy(acceptitem.nick,argv[4]);
+      acceptitem.setnick(argv[4]);
       sscanf(argv[5],"%u",&in.s_addr);
       in.s_addr=ntohl(in.s_addr);
       strcpy(acceptitem.ip,inet_ntoa(in));
@@ -69,7 +69,7 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
 	Tcl_SetResult(interp,"acceptlist: Invalid arguments given",TCL_VOLATILE);
 	return TCL_ERROR;
       }
-      strcpy(acceptitem.nick,argv[4]);
+      acceptitem.setnick(argv[4]);
       sscanf(argv[5],"%u",&in.s_addr);
       in.s_addr=ntohl(in.s_addr);
       strcpy(acceptitem.ip,inet_ntoa(in));
@@ -101,9 +101,9 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
     acceptitem.id=atoi(argv[3]);
     if((acceptitemp=windowp->server->acceptlist.find(acceptitem))) {
       if(acceptitemp->type==DCCCHAT) {
-	dccp=new tdcc(windowp->server,acceptitemp->nick,acceptitemp->ip,acceptitemp->port);
+	dccp=new tdcc(windowp->server,acceptitemp->getnick(),acceptitemp->ip,acceptitemp->port);
       } else if(acceptitemp->type==DCCFILEGET) {
-	dccp=new tdcc(windowp->server,acceptitemp->nick,acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,0,acceptitemp->file);
+	dccp=new tdcc(windowp->server,acceptitemp->getnick(),acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,0,acceptitemp->file);
       } else {
 	Tcl_SetResult(interp,"acceptlist: Invalid accept type",TCL_STATIC);
 	return TCL_ERROR;
@@ -132,7 +132,7 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
 	Tcl_SetResult(interp,"usage: acceptlist overwrite <idtag> (Only DCC File Gets can use the overwrite option.)",TCL_STATIC);
 	return TCL_ERROR;
       }
-      dccp=new tdcc(windowp->server,acceptitemp->nick,acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,0,argv[4]);
+      dccp=new tdcc(windowp->server,acceptitemp->getnick(),acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,0,argv[4]);
       if(dccp->errortest) delete dccp;
       return TCL_OK;
     } else {
@@ -149,7 +149,7 @@ int TT_Proc___template__acceptlist(TT_PROC_ARGS) {
 	Tcl_SetResult(interp,"usage: acceptlist overwrite <idtag> (Only DCC File Gets can use the overwrite option.)",TCL_STATIC);
 	return TCL_ERROR;
       }
-      dccp=new tdcc(windowp->server,acceptitemp->nick,acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,DCC_OVERWRITE,acceptitemp->file);
+      dccp=new tdcc(windowp->server,acceptitemp->getnick(),acceptitemp->ip,acceptitemp->port,acceptitemp->file,acceptitemp->size,DCC_OVERWRITE,acceptitemp->file);
       if(dccp->errortest) delete dccp;
       return TCL_OK;
     } else {
@@ -324,7 +324,7 @@ int TT_Proc___template__dccquote(TT_PROC_ARGS) {
   windows.init_trav();
   while((dccwindowp=windows.trav())) {
     if(dccwindowp->server==windowp->server&&dccwindowp->dcc) {
-      if((!strcasecmp(dccwindowp->dcc->nick,argv[2]))||(!strcasecmp(dccwindowp->name,argv[2]))) {
+      if((!strcasecmp(dccwindowp->dcc->getnick(),argv[2]))||(!strcasecmp(dccwindowp->name,argv[2]))) {
 	// DEBUG
 	//TT_EvalF(TT_ARGS,".raw.text insert end \"DCC Command (tcl.cc:1078): %q\\n\"",argv[3]);
 	dccwindowp->dcc->senddata(argv[3]);
@@ -428,22 +428,20 @@ int TT_Proc___template__ison(TT_PROC_ARGS) {
   tchan *channelp;
   twindow window;
   twindow *windowp;
-  tnick nick;
   tnick *nickp;
   if(argc!=4) {
-    Tcl_SetResult(interp,"Usage: ison <nick> <channel>",TCL_VOLATILE);
+    Tcl_SetResult(interp,"Usage: ison <nick> <channel>",TCL_STATIC);
     return TCL_ERROR;
   }
   sprintf(window.pathname,".status%s",argv[1]);
   if((windowp=windows.find(window))) {
     if(windowp->server) {
       strcpy(channel.name,argv[3]);
-      Tcl_SetResult(interp,"0",TCL_VOLATILE);
+      Tcl_SetResult(interp,"0",TCL_STATIC);
       if((channelp=windowp->server->chanlist.find(channel))) {
-	strcpy(nick.name,argv[2]);
-	channelp->nicklist.init_trav();
+	tnick nick(argv[2]);
 	if((nickp=channelp->nicklist.find(nick))) {
-	  Tcl_SetResult(interp,"1",TCL_VOLATILE);
+	  Tcl_SetResult(interp,"1",TCL_STATIC);
 	}
       }
     }
@@ -456,22 +454,20 @@ int TT_Proc___template__isop(TT_PROC_ARGS) {
   tchan *channelp;
   twindow window;
   twindow *windowp;
-  tnick nick;
   tnick *nickp;
   if(argc!=4) {
-    Tcl_SetResult(interp,"Usage: isop <nick> <channel>",TCL_VOLATILE);
+    Tcl_SetResult(interp,"Usage: isop <nick> <channel>",TCL_STATIC);
     return TCL_ERROR;
   }
   sprintf(window.pathname,".status%s",argv[1]);
   if((windowp=windows.find(window))) {
     if(windowp->server) {
       strcpy(channel.name,argv[3]); 
-      Tcl_SetResult(interp,"0",TCL_VOLATILE);
+      Tcl_SetResult(interp,"0",TCL_STATIC);
       if((channelp=windowp->server->chanlist.find(channel))) {
-	strcpy(nick.name,argv[2]);
-	channelp->nicklist.init_trav();
+	tnick nick(argv[2]);
 	if((nickp=channelp->nicklist.find(nick))) {
-	  if(nickp->oped) Tcl_SetResult(interp,"1",TCL_VOLATILE);
+	  if(nickp->oped) Tcl_SetResult(interp,"1",TCL_STATIC);
 	}
       }
     }
@@ -484,22 +480,20 @@ int TT_Proc___template__isvoice(TT_PROC_ARGS) {
   tchan *channelp;
   twindow window;
   twindow *windowp;
-  tnick nick;
   tnick *nickp;
   if(argc!=4) {
-    Tcl_SetResult(interp,"Usage: isvoice <nick> <channel>",TCL_VOLATILE);
+    Tcl_SetResult(interp,"Usage: isvoice <nick> <channel>",TCL_STATIC);
     return TCL_ERROR;
   }
   sprintf(window.pathname,".status%s",argv[1]);
   if((windowp=windows.find(window))) {
     if(windowp->server) {
       strcpy(channel.name,argv[3]);
-      Tcl_SetResult(interp,"0",TCL_VOLATILE);
+      Tcl_SetResult(interp,"0",TCL_STATIC);
       if((channelp=windowp->server->chanlist.find(channel))) {
-	strcpy(nick.name,argv[2]);
-	channelp->nicklist.init_trav();
+	tnick nick(argv[2]);
 	if((nickp=channelp->nicklist.find(nick))) {
-	  if(nickp->voiced) Tcl_SetResult(interp,"1",TCL_VOLATILE);
+	  if(nickp->voiced) Tcl_SetResult(interp,"1",TCL_STATIC);
 	}
       }
     }
@@ -549,7 +543,7 @@ int TT_Proc___template__modenicks(TT_PROC_ARGS) {
 	channelp->nicklist.init_trav();
 	while((nickp=channelp->nicklist.trav())) {
 	  if(assemble.length()) assemble+=" ";
-	  assemble+=nickp->entry;
+	  assemble+=nickp->getentry();
 	}
 	Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
       }
@@ -612,7 +606,7 @@ int TT_Proc___template__mynick(TT_PROC_ARGS) {
     sprintf(window.pathname,".status%s",argv[1]);
     if((windowp=windows.find(window))) {
       if(windowp->server) {
-	Tcl_SetResult(interp,windowp->server->mynick,TCL_VOLATILE);
+	Tcl_SetResult(interp,(char*)windowp->server->getmynick(),TCL_VOLATILE);
       }
     }
   }
@@ -638,7 +632,7 @@ int TT_Proc___template__nicks(TT_PROC_ARGS) {
 	channelp->nicklist.init_trav();
 	while((nickp=channelp->nicklist.trav())) {
 	  if(assemble.length()) assemble+=" ";
-	  assemble+=nickp->name;
+	  assemble+=nickp->getname();
 	}
 	Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
       }
@@ -717,7 +711,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
           windows.init_trav();
 	  while((dccwindowp=windows.trav())) {
 	    if(dccwindowp->server==windowp->server&&dccwindowp->dcc) {
-	      if((!strcasecmp(dccwindowp->dcc->nick,argv[3]))||(!strcasecmp(dccwindowp->name,argv[3]))) {
+	      if((!strcasecmp(dccwindowp->dcc->getnick(),argv[3]))||(!strcasecmp(dccwindowp->name,argv[3]))) {
 		Tcl_SetResult(interp,dccwindowp->pathname,TCL_VOLATILE);
 		return TCL_OK;
 	      }
@@ -731,7 +725,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
 	  }
 	}
 	if(!strcasecmp(argv[2],"query")) {
-	  strcpy(query.name,argv[3]);
+	  query.setname(argv[3]);
 	  if((queryp=windowp->server->querylist.find(query))) {
 	    Tcl_SetResult(interp,queryp->pathname,TCL_VOLATILE);
 	  }
@@ -742,7 +736,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
 	    Tcl_SetResult(interp,channelp->pathname,TCL_VOLATILE);
 	    return TCL_OK;
 	  }
-	  strcpy(query.name,argv[3]);
+	  query.setname(argv[3]);
 	  if((queryp=windowp->server->querylist.find(query))) {
 	    Tcl_SetResult(interp,queryp->pathname,TCL_VOLATILE);
 	    return TCL_OK;
@@ -750,7 +744,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
 	  windows.init_trav();
 	  while((dccwindowp=windows.trav())) {
 	    if(dccwindowp->server==windowp->server&&dccwindowp->dcc) {
-	      if((!strcasecmp(dccwindowp->dcc->nick,argv[3]))||(!strcasecmp(dccwindowp->name,argv[3]))) {
+	      if((!strcasecmp(dccwindowp->dcc->getnick(),argv[3]))||(!strcasecmp(dccwindowp->name,argv[3]))) {
 		Tcl_SetResult(interp,dccwindowp->pathname,TCL_VOLATILE);
 		return TCL_OK;
 	      }
@@ -765,7 +759,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
 	Tcl_SetResult(interp,channelp->pathname,TCL_VOLATILE);
 	return TCL_OK;
       }
-      strcpy(query.name,argv[2]);
+      query.setname(argv[2]);
       if((queryp=windowp->server->querylist.find(query))) {
 	Tcl_SetResult(interp,queryp->pathname,TCL_VOLATILE);
 	return TCL_OK;
@@ -773,7 +767,7 @@ int TT_Proc___template__pathname(TT_PROC_ARGS) {
       windows.init_trav();
       while((dccwindowp=windows.trav())) {
 	if(dccwindowp->server==windowp->server&&dccwindowp->dcc) {
-	  if((!strcasecmp(dccwindowp->dcc->nick,argv[2]))||(!strcasecmp(dccwindowp->name,argv[2]))) {
+	  if((!strcasecmp(dccwindowp->dcc->getnick(),argv[2]))||(!strcasecmp(dccwindowp->name,argv[2]))) {
 	    Tcl_SetResult(interp,dccwindowp->pathname,TCL_VOLATILE);
 	    return TCL_OK;
 	  }
@@ -854,7 +848,7 @@ int TT_Proc___template__queries(TT_PROC_ARGS) {
       windowp->server->querylist.init_trav();
       while((queryp=windowp->server->querylist.trav())) {
 	if(assemble.length()) assemble+=" ";
-	assemble+=queryp->name;
+	assemble+=queryp->getname();
       }
       Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
     }
