@@ -1,5 +1,18 @@
 #include "config.h"
 
+/* This function lowercases the passed in string. */
+void lc(char *s);
+
+/* This function behaves like malloc() only it checks to ensure that the memory
+   was actually allocated.  If the allocation fails, it prints a message to
+   stderr and exits. */
+void *mymalloc(int size);
+
+/* This function behaves like strdup() only it checks to ensure that the memory
+   was actually allocated.  If the allocation fails, it prints a message to
+   stderr and exits. */
+char *mystrdup(const char *s);
+
 /* This function returns a pointer to a statically allocated block of memory
    that contains the string representation of the given integer */
 char *strnum(int num);
