@@ -856,7 +856,7 @@ int TT_Proc_parseentry(TT_PROC_ARGS) {
 	  if(!strncmp(argv[1],".query",6)) {
 	    strcpy(query.pathname,argv[1]);
 	    if((queryp=windowp->server->querylist.find(query))) {
-	      sprintf(temp,"PRIVMSG %s :%s",queryp->name,position);
+	      sprintf(temp,"PRIVMSG %s :%s",queryp->getname(),position);
 	      windowp->server->senddata(temp);
 	    }
 	  }
@@ -1048,7 +1048,7 @@ int TT_Proc_say(TT_PROC_ARGS) {
     strcpy(query.pathname,window.pathname);
     queryp=windowp->server->querylist.find(query);
     while(position) {
-      sprintf(temp,"PRIVMSG %s :%s",queryp->name,position);
+      sprintf(temp,"PRIVMSG %s :%s",queryp->getname(),position);
       windowp->server->senddata(temp);
       fdisplay("OUTGOING_TEXT",windowp->server->index,2,window.pathname,position);
       position=strtok(NULL,"\n");
